summaryrefslogtreecommitdiffstats
path: root/ipalib/errors.py
diff options
context:
space:
mode:
authorMartin Basti <mbasti@redhat.com>2014-07-09 18:10:50 +0200
committerPetr Viktorin <pviktori@redhat.com>2014-08-11 16:01:38 +0200
commitca001814abe533f19498d4207b5233eff17549a5 (patch)
tree251a20d701edcb14194751c8f704720f45845cfc /ipalib/errors.py
parent6bb240fa2cf6ce257376241d0a779ca5cc96078e (diff)
downloadfreeipa-ca001814abe533f19498d4207b5233eff17549a5.tar.gz
freeipa-ca001814abe533f19498d4207b5233eff17549a5.tar.xz
freeipa-ca001814abe533f19498d4207b5233eff17549a5.zip
Allow to add host if AAAA record exists
http://fedorahosted.org/freeipa/ticket/4164 Reviewed-By: Petr Viktorin <pviktori@redhat.com>
Diffstat (limited to 'ipalib/errors.py')
-rw-r--r--ipalib/errors.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/ipalib/errors.py b/ipalib/errors.py
index 09b7779e9..14e052990 100644
--- a/ipalib/errors.py
+++ b/ipalib/errors.py
@@ -1119,19 +1119,19 @@ class DefaultGroupError(ExecutionError):
class DNSNotARecordError(ExecutionError):
"""
**4019** Raised when a hostname is not a DNS A record
For example:
>>> raise DNSNotARecordError()
Traceback (most recent call last):
...
DNSNotARecordError: Host does not have corresponding DNS A record
"""
errno = 4019
- format = _('Host does not have corresponding DNS A record')
+ format = _('Host does not have corresponding DNS A/AAAA record')
class ManagedGroupError(ExecutionError):
"""
@@ -1119,19 +1119,19 @@ class DefaultGroupError(ExecutionError):
class DNSNotARecordError(ExecutionError):
"""
- **4019** Raised when a hostname is not a DNS A record
+ **4019** Raised when a hostname is not a DNS A/AAAA record
For example:
>>> raise DNSNotARecordError()
@@ -1119,19 +1119,19 @@ class DefaultGroupError(ExecutionError):
Traceback (most recent call last):
...
- DNSNotARecordError: Host does not have corresponding DNS A record
+ DNSNotARecordError: Host does not have corresponding DNS A/AAAA record
"""
errno = 4019